AgendaLabels class

Agenda labels.

Constructors

AgendaLabels({String document = 'Agenda', String when = 'When', String where = 'Where', String time = 'Time', String item = 'Item', String owner = 'Owner'})
AgendaLabels API.
const

Properties

document → String
document API.
final
hashCode → int
The hash code for this object.
no setterinherited
item → String
item API.
final
owner → String
owner API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → String
time API.
final
when → String
when API.
final
where → String
where API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited