BriefingLabels class

Briefing labels.

Constructors

BriefingLabels({String document = 'Briefing', String next = 'Next'})
BriefingLabels API.
const

Properties

document → String
document API.
final
hashCode → int
The hash code for this object.
no setterinherited
next → String
next API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited