CertificateTemplate class

Landscape certificate. Body is one paragraph the caller writes.

Constructors

CertificateTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.people, SfntFont? font, SfntFont? fontBold, required TemplateParty issuer, required String recipient, required String award, String body = '', CertificateLabels labels = const CertificateLabels(), String date = '', List<SignSlot> signs = const <SignSlot>[], String footer = ''})
CertificateTemplate API.

Properties

award → String
award API.
final
body → String
body API.
final
date → String
date API.
final
direction → TextDirection
direction API.
final
font → SfntFont?
font API.
final
fontBold → SfntFont?
fontBold API.
final
footer API.
final
hashCode → int
The hash code for this object.
no setterinherited
issuer → TemplateParty
issuer API.
final
labels → CertificateLabels
labels API.
final
recipient → String
recipient API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signs → List<SignSlot>
signs API.
final
theme → TemplateTheme
theme API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → Uint8List
save API.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited