CheckItem class

One row in a checklist or inspection.

Constructors

CheckItem({required String label, CheckMark mark = CheckMark.open, String note = ''})
CheckItem API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
label → String
label API.
final
mark → CheckMark
mark API.
final
note → String
note API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited