ChecklistLabels class

Checklist labels. marks maps each CheckMark to the printed word.

Constructors

ChecklistLabels({String document = 'Checklist', String item = 'Item', String mark = 'Mark', String note = 'Note', Map<CheckMark, String> marks = const <CheckMark, String>{CheckMark.open : 'Open', CheckMark.done : 'Done', CheckMark.pass : 'Pass', CheckMark.fail : 'Fail', CheckMark.na : 'N/A'}})
ChecklistLabels API.
const

Properties

document → String
document API.
final
hashCode → int
The hash code for this object.
no setterinherited
item → String
item API.
final
mark → String
mark API.
final
marks → Map<CheckMark, String>
marks API.
final
note → String
note API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
word(CheckMark value) → String
word API.

Operators

operator ==(Object other) → bool
The equality operator.
inherited