ChecklistTemplate class
Grouped checklist.
Constructors
-
ChecklistTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.operations, SfntFont? font, SfntFont? fontBold, required TemplateParty owner, List<
CheckGroup> groups = const <CheckGroup>[], ChecklistLabels labels = const ChecklistLabels(), }) - ChecklistTemplate API.
Properties
- direction → TextDirection
-
direction API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
-
groups
→ List<
CheckGroup> -
groups API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → ChecklistLabels
-
labels API.
final
- owner → TemplateParty
-
owner API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → TemplateTheme
-
theme API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited