CommissionNoteTemplate class

Commission note.

Implemented types

Constructors

CommissionNoteTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme? theme, SfntFont? font, SfntFont? fontBold, required TemplateParty from, TemplateParty? to, SheetLabels? labels, String number = '', String date = '', String extra = '', String subject = '', String recipient = '', List<SheetRow> rows = const <SheetRow>[], List<String> paragraphs = const <String>[], List<TemplateSection> sections = const <TemplateSection>[], List<(String, String)> metrics = const <(String, String)>[], List<ChartPoint>? chart, String chartTitle = '', MoneyTotals? totals, String? notes, String footer = '', List<SignSlot> signs = const <SignSlot>[]})
CommissionNoteTemplate API.

Properties

chart → List<ChartPoint>?
chart API.
final
chartTitle → String
chartTitle API.
final
date → String
date API.
final
direction → TextDirection
direction API.
final
extra → String
extra API.
final
font → SfntFont?
font API.
final
fontBold → SfntFont?
fontBold API.
final
footer API.
final
from → TemplateParty
from API.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → SheetLabels
labels API.
final
metrics → List<(String, String)>
metrics API.
final
notes → String?
notes API.
final
number → String
number API.
final
paragraphs → List<String>
paragraphs API.
final
recipient → String
recipient API.
final
rows → List<SheetRow>
rows API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sections → List<TemplateSection>
sections API.
final
signs → List<SignSlot>
signs API.
final
subject → String
subject API.
final
theme → TemplateTheme
theme API.
final
to → TemplateParty?
to API.
final
totals → MoneyTotals?
totals API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → Uint8List
save API.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited