ExpenseLine class
One expense row.
Constructors
- ExpenseLine({required String date, required String category, String note = '', required String amount})
-
ExpenseLine API.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited