KpiLabels class

KPI sheet labels.

Constructors

KpiLabels({String document = 'KPI sheet', String period = 'Period', String notes = 'Notes'})
KpiLabels API.
const

Properties

document → String
document API.
final
hashCode → int
The hash code for this object.
no setterinherited
notes → String
notes API.
final
period → String
period API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited