LetterLabels class

Letter labels. Body text lives on the template, not here.

Constructors

LetterLabels({String document = 'Letter', String to = 'To', String subject = 'Subject', String closing = 'Yours sincerely'})
LetterLabels API.
const

Properties

closing → String
closing API.
final
document → String
document API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
subject API.
final
to → String
to API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited