ListingLabels class

Record listing labels.

Constructors

ListingLabels({String document = 'Listing', String filter = 'Filter', String count = 'Rows'})
ListingLabels API.
const

Properties

count → String
count API.
final
document → String
document API.
final
filter → String
filter API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited