MemoLabels class

Memo labels.

Constructors

MemoLabels({String document = 'Memo', String to = 'To', String from = 'From', String date = 'Date', String subject = 'Subject'})
MemoLabels API.
const

Properties

date → String
date API.
final
document → String
document API.
final
from → String
from API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String
subject API.
final
to → String
to API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited