PayslipLabels class

Payslip labels.

Constructors

PayslipLabels({String document = 'Payslip', String employee = 'Employee', String period = 'Period', String paidOn = 'Paid on', String earnings = 'Earnings', String deductions = 'Deductions', String item = 'Item', String amount = 'Amount', String net = 'Net pay'})
PayslipLabels API.
const

Properties

amount → String
amount API.
final
deductions → String
deductions API.
final
document → String
document API.
final
earnings → String
earnings API.
final
employee → String
employee API.
final
hashCode → int
The hash code for this object.
no setterinherited
item → String
item API.
final
net → String
net API.
final
paidOn → String
paidOn API.
final
period → String
period API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited