ReceiptTemplate class

Receipt. method uses the extra label.

Constructors

ReceiptTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.commerce, SfntFont? font, SfntFont? fontBold, required TemplateParty seller, required TemplateParty buyer, List<TradeLine> lines = const <TradeLine>[], required MoneyTotals totals, TradeLabels labels = const TradeLabels(document: 'Receipt', extra: 'Paid by'), String number = '', String date = '', String method = '', String? notes, String footer = ''})
ReceiptTemplate API.

Properties

buyer → TemplateParty
buyer API.
final
date → String
date API.
final
direction → TextDirection
direction API.
final
font → SfntFont?
font API.
final
fontBold → SfntFont?
fontBold API.
final
footer API.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → TradeLabels
labels API.
final
lines → List<TradeLine>
lines API.
final
method → String
method API.
final
notes → String?
notes API.
final
number → String
number API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seller → TemplateParty
seller API.
final
theme → TemplateTheme
theme API.
final
totals → MoneyTotals
totals API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → Uint8List
save API.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited