SheetRow class

One table row. Cells follow SheetLabels.columns.

Constructors

SheetRow(List<String> cells)
SheetRow API.
const

Properties

cells → List<String>
cells API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited