SheetTemplate class
A customizable sheet. Named suite classes wrap this with domain defaults.
Constructors
-
SheetTemplate({required SheetKind kind, TextDirection direction = TextDirection.ltr, required TemplateTheme theme, SfntFont? font, SfntFont? fontBold, required TemplateParty owner, TemplateParty? other, SheetLabels labels = const SheetLabels(document: 'Report'), String number = '', String date = '', String extra = '', String subject = '', String recipient = '', List<
SheetRow> rows = const <SheetRow>[], List<String> paragraphs = const <String>[], List<TemplateSection> sections = const <TemplateSection>[], List<(String, String)> metrics = const <(String, String)>[], List<ChartPoint> ? chart, String chartTitle = '', MoneyTotals? totals, String? notes, List<SignSlot> signs = const <SignSlot>[], bool landscape = false, SheetSkin? skin}) - SheetTemplate API.
Properties
-
chart
→ List<
ChartPoint> ? -
chart API.
final
- chartTitle → String
-
chartTitle API.
final
- date → String
-
date API.
final
- direction → TextDirection
-
direction API.
final
- extra → String
-
extra API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → SheetKind
-
kind API.
final
- labels → SheetLabels
-
labels API.
final
- landscape → bool
-
landscape API.
final
-
metrics
→ List<
(String, String)> -
metrics API.
final
- notes → String?
-
notes API.
final
- number → String
-
number API.
final
- other → TemplateParty?
-
other API. End party. Omitted when null.
final
- owner → TemplateParty
-
owner API. Start party. Also the document author.
final
-
paragraphs
→ List<
String> -
paragraphs API.
final
- recipient → String
-
recipient API. Used by SheetKind.award.
final
-
rows
→ List<
SheetRow> -
rows API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
TemplateSection> -
sections API.
final
-
signs
→ List<
SignSlot> -
signs API.
final
- skin → SheetSkin
-
skin API. The page composition, not the words.
final
- subject → String
-
subject API. When set, it becomes the band title.
final
- theme → TemplateTheme
-
theme API.
final
- totals → MoneyTotals?
-
totals API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited