SignSlot class

One signature slot. Empty name leaves a line to sign on paper.

Constructors

SignSlot({required String role, String name = ''})
SignSlot API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
name API.
final
role → String
role API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited