StatementTemplate class
Account statement.
Constructors
-
StatementTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.finance, SfntFont? font, SfntFont? fontBold, required TemplateParty issuer, required TemplateParty account, List<
StatementLine> lines = const <StatementLine>[], StatementLabels labels = const StatementLabels(), String period = '', String opening = '', String closing = '', String? notes, }) - StatementTemplate API.
Properties
- account → TemplateParty
-
account API.
final
- closing → String
-
closing API.
final
- direction → TextDirection
-
direction API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuer → TemplateParty
-
issuer API.
final
- labels → StatementLabels
-
labels API.
final
-
lines
→ List<
StatementLine> -
lines API.
final
- notes → String?
-
notes API.
final
- opening → String
-
opening API.
final
- period → String
-
period API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → TemplateTheme
-
theme API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited