Writes a multi-page document in direction.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
save(
{required String title, String author = '', required TextDirection direction, required TemplateTheme theme, SfntFont? font, SfntFont? fontBold, PdfPageFormat? pageFormat, PageOrientation orientation = PageOrientation.natural, required List< Widget> build(Context context)}) → Uint8List - save API.