TemplateParty class

A named party: seller, buyer, employee, clinic.

Constructors

TemplateParty({required String name, List<String> lines = const <String>[]})
TemplateParty API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lines → List<String>
lines API.
final
name → String
name API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited