TemplateRef class
One entry in TemplateCatalog. className is the type to construct.
Constructors
- TemplateRef({required String id, required TemplateCategory category, required String className, required String nameEn, required String nameAr, required String blurbEn, required String blurbAr})
-
TemplateRef API.
const
Properties
- blurbAr → String
-
blurbAr API.
final
- blurbEn → String
-
blurbEn API.
final
- category → TemplateCategory
-
category API.
final
- className → String
-
className API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
id API.
final
- nameAr → String
-
nameAr API.
final
- nameEn → String
-
nameEn API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
blurb(
bool arabic) → String - blurb API.
-
name(
bool arabic) → String - name API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited