TemplateSection class

Heading plus body. Used by memos and briefings.

Constructors

TemplateSection({required String heading, required String body})
TemplateSection API.
const

Properties

body → String
body API.
final
hashCode → int
The hash code for this object.
no setterinherited
heading → String
heading API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited