TemplateTheme class
Colors and page size. Pass a different accent per domain or brand.
Constructors
- TemplateTheme({String accent = '0F766E', String ink = '1C1917', String muted = '57534E', String wash = 'F0FDFA', String line = '99F6E4', String onAccent = 'F0FDFA', PdfPageFormat pageFormat = PdfPageFormat.a4, EdgeInsets margin = const EdgeInsets.fromLTRB(36, 32, 36, 42)})
-
TemplateTheme API.
const
Properties
- accent → String
-
accent API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ink → String
-
ink API.
final
- line → String
-
line API.
final
- margin → EdgeInsets
-
margin API.
final
- muted → String
-
muted API.
final
- onAccent → String
-
onAccent API.
final
- pageFormat → PdfPageFormat
-
pageFormat API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wash → String
-
wash API.
final
Methods
-
copyWith(
{String? accent, String? ink, String? muted, String? wash, String? line, String? onAccent, PdfPageFormat? pageFormat, EdgeInsets? margin}) → TemplateTheme - copyWith API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited