TradeLabels class

Column headings for a trade table. Replace every string for another language.

Constructors

TradeLabels({String document = 'Invoice', String from = 'From', String to = 'To', String number = 'Number', String date = 'Date', String extra = 'Due', String description = 'Description', String quantity = 'Qty', String unit = 'Unit', String amount = 'Amount', String subtotal = 'Subtotal', String tax = 'Tax', String total = 'Total', String notes = 'Notes'})
TradeLabels API.
const

Properties

amount → String
amount API.
final
date → String
date API.
final
description → String
description API.
final
document → String
document API.
final
extra → String
extra API. Due date, valid until, payment, or ship date.
final
from → String
from API.
final
hashCode → int
The hash code for this object.
no setterinherited
notes → String
notes API.
final
number → String
number API.
final
quantity → String
quantity API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtotal → String
subtotal API.
final
tax → String
tax API.
final
to → String
to API.
final
total → String
total API.
final
unit → String
unit API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited