TradeLine class

One trade line. Quantity, unit, and amount are already formatted.

Constructors

TradeLine({required String description, String quantity = '', String unit = '', String amount = '', String detail = ''})
TradeLine API.
const

Properties

amount → String
amount API.
final
description → String
description API.
final
detail → String
detail API. Ordered vs shipped, or a second quantity.
final
hashCode → int
The hash code for this object.
no setterinherited
quantity → String
quantity API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit → String
unit API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited