Alignment class

Flutter alignment: x/y in -1..1 (top-left is -1,-1).

Inheritance

Constructors

Alignment(double x, double y)
Alignment API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x → double
x API.
final
y → double
y API.
final

Methods

alongOffset(PwSize parent, PwSize child) → PwOffset
alongOffset API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(TextDirection direction) → Alignment
Physical alignment for direction.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bottomCenter → const Alignment
bottomCenter API.
bottomLeft → const Alignment
bottomLeft API.
bottomRight → const Alignment
bottomRight API.
center → const Alignment
center API.
centerLeft → const Alignment
centerLeft API.
centerRight → const Alignment
centerRight API.
topCenter → const Alignment
topCenter API.
topLeft → const Alignment
topLeft API.
topRight → const Alignment
topRight API.