AlignmentDirectional class

Alignment that flips with TextDirection. start is -1 at the start edge.

Inheritance

Constructors

AlignmentDirectional(double start, double y)
AlignmentDirectional API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → double
start API. -1 is the start edge, 1 the end edge.
final
y → double
y API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(TextDirection direction) → Alignment
Physical alignment for direction.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bottomCenter → const AlignmentDirectional
bottomCenter API.
bottomEnd → const AlignmentDirectional
bottomEnd API.
bottomStart → const AlignmentDirectional
bottomStart API.
center → const AlignmentDirectional
center API.
centerEnd → const AlignmentDirectional
centerEnd API.
centerStart → const AlignmentDirectional
centerStart API.
topCenter → const AlignmentDirectional
topCenter API.
topEnd → const AlignmentDirectional
topEnd API.
topStart → const AlignmentDirectional
topStart API.