AlignmentGeometry class abstract

Physical or start/end alignment. Resolve before Alignment.alongOffset.

Implementers

Constructors

AlignmentGeometry()
AlignmentGeometry API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(TextDirection direction) → Alignment
Physical alignment for direction.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited