BorderSide class

One side of a border.

Constructors

BorderSide({String color = '000000', double width = 1})
BorderSide API.
const

Properties

color → String
color API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
width API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

none → const BorderSide
none API.