BoxDecoration class

Box decoration (fill + stroke).

Constructors

BoxDecoration({String? color, LinearGradient? gradient, Border? border, double borderRadius = 0, BoxShape shape = BoxShape.rectangle})
BoxDecoration API.
const

Properties

border → Border?
border API.
final
borderRadius → double
borderRadius API.
final
color → String?
color API.
final
gradient → LinearGradient?
gradient API. Painted instead of color when set.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → BoxShape
shape API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited