Bullet class

Bullet / numbered list of widgets.

Inheritance

Constructors

Bullet({required String text, TextStyle? style, String bullet = '•'})
Bullet API.
const

Properties

bullet → String
bullet API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
style API.
final
text → String
text API.
final

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited