Center class

Same constructor as Flutter Center.

Inheritance

Constructors

Center({required Widget child, double? widthFactor, double? heightFactor})
Center API.
const

Properties

alignment → AlignmentGeometry
alignment API.
finalinherited
child → Widget
child API.
finalinherited
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
heightFactor → double?
heightFactor API.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widthFactor → double?
widthFactor API.
finalinherited

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
inherited
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited