size property
size API. Null uses the incoming max when bounded, else the children.
Implementation
final PwSize Function(BoxConstraints constraints)? size;
size API. Null uses the incoming max when bounded, else the children.
final PwSize Function(BoxConstraints constraints)? size;