CustomPaint class

Custom paint. size is used only when child is null.

Inheritance

Constructors

CustomPaint({PdfCustomPainter? painter, PdfCustomPainter? foregroundPainter, Widget? child, PwSize? size})
CustomPaint API.
const

Properties

child → Widget?
child API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
foregroundPainter → PdfCustomPainter?
foregroundPainter API.
final
hashCode → int
The hash code for this object.
no setterinherited
painter → PdfCustomPainter?
painter API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → PwSize?
size API.
final

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited