Divider class

Horizontal rule.

Inheritance

Constructors

Divider({double? height, double? thickness, String? color, double indent = 0, double endIndent = 0})
Divider API.
const

Properties

color → String?
color API.
final
endIndent → double
endIndent API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
height API.
final
indent → double
indent API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thickness → double?
thickness API.
final

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited