EdgeInsets class
Insets around a child.
- Inheritance
-
- Object
- EdgeInsetsGeometry
- EdgeInsets
Constructors
- EdgeInsets.all(double value)
-
all API.
const
- EdgeInsets.fromLTRB(double left, double top, double right, double bottom)
-
EdgeInsets API.
const
- EdgeInsets.only({double left = 0, double top = 0, double right = 0, double bottom = 0})
-
only API.
const
- EdgeInsets.symmetric({double vertical = 0, double horizontal = 0})
-
symmetric API.
const
Properties
- bottom → double
-
bottom API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontal → double
-
horizontal API.
no setter
- left → double
-
left API.
final
- right → double
-
right API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- top → double
-
top API.
final
- vertical → double
-
vertical API.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
TextDirection direction) → EdgeInsets -
Physical insets for
direction.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- zero → const EdgeInsets
- zero API.