EdgeInsetsDirectional class

Insets that flip with TextDirection. start is left in LTR, right in RTL.

Inheritance

Constructors

EdgeInsetsDirectional.all(double value)
all API.
const
EdgeInsetsDirectional.fromSTEB(double start, double top, double end, double bottom)
EdgeInsetsDirectional API.
const
EdgeInsetsDirectional.only({double start = 0, double top = 0, double end = 0, double bottom = 0})
only API.
const

Properties

bottom → double
bottom API.
final
end → double
end API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → double
start API.
final
top → double
top API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(TextDirection direction) → EdgeInsets
Physical insets for direction.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

zero → const EdgeInsetsDirectional
zero API.