FittedBox class

Scales child to fit the incoming box.

Inheritance

Constructors

FittedBox({BoxFit fit = BoxFit.contain, AlignmentGeometry alignment = Alignment.center, required Widget child})
FittedBox API.
const

Properties

alignment → AlignmentGeometry
alignment API.
final
child → Widget
child API.
final
fit → BoxFit
fit API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited