Flex class
Row or column from direction.
Constructors
-
Flex({required Axis direction, List<
Widget> children = const <Widget>[], MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisSize mainAxisSize = MainAxisSize.max}) -
Flex API.
const
Properties
-
children
→ List<
Widget> -
children API.
final
- crossAxisAlignment → CrossAxisAlignment
-
crossAxisAlignment API.
final
- direction → Axis
-
direction API.
final
-
flowChildren
→ List<
Widget> ? -
Vertical columns flow as separate MultiPage children so a nested Table can span.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAxisAlignment → MainAxisAlignment
-
mainAxisAlignment API.
final
- mainAxisSize → MainAxisSize
-
mainAxisSize API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
layout(
Context context, BoxConstraints constraints) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited