GridView class
Fixed-count grid.
Constructors
-
GridView({int crossAxisCount = 2, List<
Widget> children = const <Widget>[], double childAspectRatio = 1, double crossAxisSpacing = 8, double mainAxisSpacing = 8}) -
GridView API.
const
-
GridView.count({required int crossAxisCount, required List<
Widget> children, double childAspectRatio = 1, double crossAxisSpacing = 8, double mainAxisSpacing = 8}) -
count API.
factory
Properties
- childAspectRatio → double
-
childAspectRatio API.
final
-
children
→ List<
Widget> -
children API.
final
- crossAxisCount → int
-
crossAxisCount API.
final
- crossAxisSpacing → double
-
crossAxisSpacing API.
final
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainAxisSpacing → double
-
mainAxisSpacing API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
layout(
Context context, BoxConstraints constraints) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited