GroupBox class

Multi-child box with absolute child origins (relative to this box).

Inheritance

Constructors

GroupBox(PwSize size, List<(PwBox, PwOffset)> children, {BoxDecoration? background})
GroupBox API.

Properties

background → BoxDecoration?
background API.
final
baseline → double?
Distance from the top of this box to the alphabetic baseline, if any.
no setterinherited
children → List<(PwBox, PwOffset)>
children API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → PwSize
size API.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noteDestination(Context context, PwOffset offset) → void
Record heading destinations once page placement is known.
override
paint(Context context, PwOffset offset) → void
paint API.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited