Header class
Heading 0–5. Registers a TOC / outline entry.
Constructors
- Header({int level = 1, String? text, Widget? child, EdgeInsets? margin, EdgeInsets? padding, TextStyle? textStyle, String? title})
- Header API.
Properties
- child → Widget?
-
child API.
final
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- level → int
-
level API.
final
- margin → EdgeInsets?
-
margin API.
final
- padding → EdgeInsets?
-
padding API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
text API.
final
- textStyle → TextStyle?
-
textStyle API.
final
- title → String?
-
title API.
final
Methods
-
layout(
Context context, BoxConstraints constraints) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited