ListTile class

Leading, title, subtitle, and trailing. Slots, not a document.

Inheritance

Constructors

ListTile({Widget? leading, required Widget title, Widget? subtitle, Widget? trailing, EdgeInsetsGeometry? contentPadding})
ListTile API.
const

Properties

contentPadding → EdgeInsetsGeometry?
contentPadding API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
leading → Widget?
leading API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle → Widget?
subtitle API.
final
title → Widget
title API.
final
trailing → Widget?
trailing API.
final

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited