ListView class

Non-scrolling column (PDF has no viewport). Same children as Flutter ListView.

Inheritance

Constructors

ListView({List<Widget> children = const <Widget>[], double? itemExtent})
ListView API.
const
ListView.builder({required int itemCount, required Widget itemBuilder(Context context, int index), double? itemExtent})
builder API.
factory

Properties

children → List<Widget>
children API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
itemExtent → double?
itemExtent API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited