MultiPage class

Flowing multi-page section.

Inheritance

Constructors

MultiPage({PageTheme? pageTheme, PdfPageFormat? pageFormat, required BuildListCallback build, ThemeData? theme, PageOrientation? orientation, EdgeInsetsGeometry? margin, TextDirection? textDirection, BuildCallback? header, BuildCallback? footer, BuildCallback? background, BuildCallback? foreground})
MultiPage API.

Properties

footer API.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
header API.
finalinherited
pageTheme → PageTheme
pageTheme API.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited