OverflowBox class
Lets child ignore the incoming max and paint outside this box.
Constructors
- OverflowBox({AlignmentGeometry alignment = Alignment.center, double? minWidth, double? maxWidth, double? minHeight, double? maxHeight, required Widget child})
-
OverflowBox API.
const
Properties
- alignment → AlignmentGeometry
-
alignment API.
final
- child → Widget
-
child API.
final
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxHeight → double?
-
maxHeight API.
final
- maxWidth → double?
-
maxWidth API.
final
- minHeight → double?
-
minHeight API.
final
- minWidth → double?
-
minWidth API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
layout(
Context context, BoxConstraints constraints) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited