Page class

One laid-out PDF page (widget API — not PdfPage).

Implementers

Constructors

Page({PageTheme? pageTheme, PdfPageFormat? pageFormat, required BuildCallback build, ThemeData? theme, PageOrientation? orientation, EdgeInsetsGeometry? margin, TextDirection? textDirection, BuildCallback? header, BuildCallback? footer})
Page API.

Properties

footer API.
final
hashCode → int
The hash code for this object.
no setterinherited
header API.
final
pageTheme → PageTheme
pageTheme API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited