PageTheme class

Page chrome: format, margin, direction, theme.

Constructors

PageTheme({PdfPageFormat? pageFormat, ThemeData? theme, PageOrientation orientation = PageOrientation.natural, EdgeInsetsGeometry? margin, TextDirection? textDirection, BuildCallback? buildBackground, BuildCallback? buildForeground})
PageTheme API.
const

Properties

buildBackground → BuildCallback?
Optional full-page background (letterhead, colored band).
final
buildForeground → BuildCallback?
Optional full-page overlay.
final
hashCode → int
The hash code for this object.
no setterinherited
margin → EdgeInsetsGeometry?
margin API.
final
orientation → PageOrientation
orientation API.
final
pageFormat → PdfPageFormat
pageFormat API.
final
resolvedFormat → PdfPageFormat
resolvedFormat API.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → TextDirection?
textDirection API.
final
theme → ThemeData?
theme API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolvedMargin() → EdgeInsets
resolvedMargin API.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited