Paragraph class

Body paragraph with bottom margin.

Inheritance

Constructors

Paragraph({String? text, TextAlign textAlign = TextAlign.justify, TextStyle? style, EdgeInsets margin = const EdgeInsets.only(bottom: 8), EdgeInsets? padding})
Paragraph API.

Properties

flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
margin → EdgeInsets
margin API.
final
padding → EdgeInsets?
padding API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
style API.
final
text → String?
text API.
final
textAlign → TextAlign
textAlign API.
final

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited