PdfPageFormat class

Page size in typographic points.

Constructors

PdfPageFormat(double width, double height, {double marginTop = 0, double marginBottom = 0, double marginLeft = 0, double marginRight = 0, double? marginAll})
PdfPageFormat API.
const

Properties

contentHeight → double
contentHeight API.
no setter
contentWidth → double
contentWidth API.
no setter
hashCode → int
The hash code for this object.
no setterinherited
height → double
height API.
final
landscape → PdfPageFormat
landscape API.
no setter
marginBottom → double
marginBottom API.
final
marginLeft → double
marginLeft API.
final
marginRight → double
marginRight API.
final
marginTop → double
marginTop API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
width API.
final

Methods

apply(PageOrientation orientation) → PdfPageFormat
apply API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

a3 → const PdfPageFormat
a3 API.
a4 → const PdfPageFormat
a4 API.
a5 → const PdfPageFormat
a5 API.
cm → const double
cm API.
inch → const double
inch API.
legal API.
letter → const PdfPageFormat
letter API.
mm → const double
mm API.
point → const double
point API.
standard → const PdfPageFormat
standard API.