Positioned class
Absolutely positioned Stack child.
Constructors
- Positioned({double? left, double? top, double? right, double? bottom, double? width, double? height, required Widget child})
-
Positioned API.
const
- Positioned.directional({double? start, double? top, double? end, double? bottom, double? width, double? height, required Widget child})
-
Pin with
start/end, resolved from Context.textDirection.const - Positioned.fill({required Widget child})
-
fill API.
const
Properties
- bottom → double?
-
bottom API.
final
- child → Widget
-
child API.
final
- directional → bool
-
True when start/end replace left/right.
final
- end → double?
-
end API. Trailing edge when directional is true.
final
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
height API.
final
- left → double?
-
left API.
final
- right → double?
-
right API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → double?
-
start API. Leading edge when directional is true.
final
- top → double?
-
top API.
final
- width → double?
-
width API.
final
Methods
-
horizontal(
TextDirection direction) → ({double? left, double? right}) -
Physical left/right for
direction. -
layout(
Context context, BoxConstraints constraints) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited