ProxyBox class
Parent that paints a decoration then a child.
Constructors
Properties
- baseline → double?
-
Distance from the top of this box to the alphabetic baseline, if any.
no setteroverride
- baselineOverride → double?
-
Alphabetic baseline of this box, if known.
final
- child → PwBox?
-
child API.
final
- childOffset → PwOffset
-
childOffset API.
final
- decoration → BoxDecoration?
-
decoration API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onNote → void Function(Context context, PwOffset offset)?
-
Called when the page position of this box is known.
final
- onPaint → void Function(Context context, PwOffset offset)?
-
Extra paint after the child (links, overlays).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → PwSize
-
size API.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
noteDestination(
Context context, PwOffset offset) → void -
Record heading destinations once page placement is known.
override
-
paint(
Context context, PwOffset offset) → void -
paint API.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited