PwBox class abstract

Measured widget. Users subclass Widget and return a PwBox.

Implementers

Constructors

PwBox(PwSize size)
PwBox API.

Properties

baseline → double?
Distance from the top of this box to the alphabetic baseline, if any.
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → PwSize
size API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noteDestination(Context context, PwOffset offset) → void
Record heading destinations once page placement is known.
paint(Context context, PwOffset offset) → void
paint API.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited