baseline property
double?
get
baseline
Distance from the top of this box to the alphabetic baseline, if any.
Implementation
double? get baseline => null;
Distance from the top of this box to the alphabetic baseline, if any.
double? get baseline => null;