PwHeading class

Heading recorded for TOC / PDF outlines.

Constructors

PwHeading({required int level, required String title, required int pageNumber, double destY = 0})
PwHeading API.

Properties

destY ↔ double
Top-left page Y, filled when the heading is placed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
level → int
level API.
final
pageNumber → int
1-based page number.
final
placed ↔ bool
Set once the heading box has a page position.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
title API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited