PwOffset class

Top-left offset in page space.

Constructors

PwOffset(double dx, double dy)
PwOffset API.
const

Properties

dx → double
dx API.
final
dy → double
dy API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
translate(double x, double y) → PwOffset
translate API.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

zero → const PwOffset
zero API.