PwPath class

Path the caller fills in local coordinates. ClipPath clips to it.

Constructors

PwPath()
PwPath API.

Properties

hashCode → int
The hash code for this object.
no setterinherited
ops → List<PwPathOp>
ops API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOval(double x, double y, double w, double h) → void
addOval API.
addRect(double x, double y, double w, double h) → void
addRect API.
close() → void
close API.
lineTo(double x, double y) → void
lineTo API.
moveTo(double x, double y) → void
moveTo API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited