SizedBox class

Same constructors as Flutter SizedBox.

Inheritance

Constructors

SizedBox({double? width, double? height, Widget? child})
SizedBox API.
const
SizedBox.expand({Widget? child})
expand API.
const
SizedBox.shrink({Widget? child})
shrink API.
const
SizedBox.square({required double dimension, Widget? child})
square API.
const

Properties

child → Widget?
child API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height → double?
height API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
width API.
final

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited