SpanSlice class

One page-slice of a widget that can flow across MultiPage.

Constructors

SpanSlice(PwBox box, Widget? rest)
SpanSlice API.
const

Properties

box → PwBox
Content that fits the given height.
final
hashCode → int
The hash code for this object.
no setterinherited
rest → Widget?
Remainder for the next page, or null when finished.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited