TableBorder class

Interior + exterior borders for a Table (package:pdf TableBorder).

Constructors

TableBorder({BorderSide left = BorderSide.none, BorderSide top = BorderSide.none, BorderSide right = BorderSide.none, BorderSide bottom = BorderSide.none, BorderSide horizontalInside = BorderSide.none, BorderSide verticalInside = BorderSide.none})
TableBorder API.
const
TableBorder.all({String color = '000000', double width = 0.4})
Uniform border on every edge and divider.
factory
TableBorder.symmetric({BorderSide inside = BorderSide.none, BorderSide outside = BorderSide.none})
Same styling inside and outside.
factory

Properties

bottom → BorderSide
bottom API.
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalInside → BorderSide
horizontalInside API.
final
left → BorderSide
left API.
final
right API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → BorderSide
top API.
final
verticalInside → BorderSide
verticalInside API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited