TableCell class

Table cell wrapping a child widget.

Constructors

TableCell({required Widget child, int colSpan = 1, String? fill})
TableCell API.
const

Properties

child → Widget
child API.
final
colSpan → int
colSpan API.
final
fill → String?
fill API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited