TableCellVerticalAlignment enum
How a cell sits inside its row height (package:pdf TableCellVerticalAlignment).
Values
- top → const TableCellVerticalAlignment
-
Top of the row.
- middle → const TableCellVerticalAlignment
-
Vertically centered.
- bottom → const TableCellVerticalAlignment
-
Bottom of the row.
- full → const TableCellVerticalAlignment
-
Child is re-laid out to the full cell size (fills background).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TableCellVerticalAlignment> - A constant List of the values in this enum, in order of their declaration.