TableOfContent class
Two-pass TOC from Header entries.
Constructors
- TableOfContent({String title = 'Table of Contents', int minLevel = 1, int maxLevel = 3, bool showPageNumbers = true})
-
TableOfContent API.
const
Properties
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLevel → int
-
maxLevel API.
final
- minLevel → int
-
minLevel API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showPageNumbers → bool
-
showPageNumbers API.
final
- title → String
-
title API.
final
Methods
-
layout(
Context context, BoxConstraints constraints) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited