TableRow class
Table row. Same role as Flutter / package:pdf TableRow.
Constructors
-
TableRow({List<
Widget> children = const <Widget>[], bool repeat = false, BoxDecoration? decoration, TableCellVerticalAlignment? verticalAlignment}) -
TableRow API.
const
Properties
-
children
→ List<
Widget> -
children API.
final
- decoration → BoxDecoration?
-
Painted behind the whole row (alternating fills, header band).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- repeat → bool
-
When true, painted as a header row (reserved for multi-page repeat).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verticalAlignment → TableCellVerticalAlignment?
-
Overrides Table.defaultVerticalAlignment for this row.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited