TextSpan class

Text run. Same constructor as Flutter / package:pdf TextSpan.

Inheritance

Constructors

TextSpan({TextStyle? style, String? text, List<InlineSpan>? children})
TextSpan API.
const

Properties

children → List<InlineSpan>?
children API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
style API.
final
text → String?
text API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited