Widget class abstract
Constraint-layout widget. Subclass and implement layout (like RenderBox).
- Implementers
- Align
- Anchor
- AspectRatio
- Baseline
- Builder
- Bullet
- Chart
- Checkbox
- Circle
- ClipOval
- ClipPath
- ClipRect
- ClipRRect
- ConstrainedBox
- Container
- CustomMultiChildLayout
- CustomPaint
- DecoratedBox
- DefaultTextStyle
- Directionality
- Divider
- FittedBox
- Flex
- Flexible
- Footer
- FractionallySizedBox
- GridView
- Header
- Icon
- Image
- Inseparable
- IntrinsicHeight
- LayoutId
- LimitedBox
- Link
- ListTile
- ListView
- Lorem
- NewPage
- Opacity
- OverflowBox
- Padding
- Paragraph
- Placeholder
- Positioned
- PwPageOverlay
- Radio
- Rectangle
- RichText
- RotatedBox
- SizedBox
- Stack
- Switch
- Table
- TableOfContent
- Text
- TextField
- Theme
- Transform
- UrlLink
- VerticalDivider
- Watermark
- Wrap
Constructors
- Widget()
-
Widget API.
const
Properties
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
layout(
Context context, BoxConstraints constraints) → PwBox - layout API.
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void - Stamp paint. The default lays out and paints glyph by glyph.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited