WidgetSpan class

Embedded child inside RichText.

Inheritance

Constructors

WidgetSpan({required Widget child})
WidgetSpan API.
const

Properties

child → Widget
child API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited