ByteSink class

Growable little-endian byte sink used by writers.

Constructors

ByteSink({int capacity = 256})
ByteSink API.

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
length API.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(List<int> bytes) → void
add API.
i16be(int value) → void
i16be API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padTo(int alignment, [int fill = 0]) → void
padTo API.
takeBytes() → Uint8List
takeBytes API.
toBytes() → Uint8List
toBytes API.
toString() → String
A string representation of this object.
inherited
u16be(int value) → void
u16be API.
u16le(int value) → void
u16le API.
u32be(int value) → void
u32be API.
u32le(int value) → void
u32le API.
u64le(int value) → void
u64le API.
u8(int value) → void
u8 API.

Operators

operator ==(Object other) → bool
The equality operator.
inherited