CallNode class

Class CallNode.

Inheritance

Constructors

CallNode(String name, List<FormulaNode> args)
CallNode API.

Properties

args → List<FormulaNode>
args API.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
name API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

eval(FormulaContext ctx) → Object?
eval API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited