CellNode class
Class CellNode.
- Inheritance
-
- Object
- FormulaNode
- CellNode
Constructors
- CellNode(SmlCellRef ref, {String? sheetName})
- CellNode API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref → SmlCellRef
-
ref API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sheetName → String?
-
sheetName API.
final
Methods
-
eval(
FormulaContext ctx) → Object? -
eval API.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited