DocxPlainReader class abstract final

Extracts plain paragraphs, tables, and hyperlinks from a .docx package.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

paragraphs(Uint8List bytes, {String? password}) → String
paragraphs API.
read(Uint8List bytes, {String? password}) → ({List<DocxHyperlink> hyperlinks, List<String> paragraphs, List<List<List<String>>> tables})