FormulaEvaluator class

Class FormulaEvaluator.

Constructors

FormulaEvaluator()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

applyInput(SmlWorkbook book, SmlWorksheet sheet, SmlCell cell, String text) → void
Writes a typed value or formula into cell and caches the result.
evaluate(String source, FormulaContext ctx) → Object?
evaluate API.
evaluateCell(SmlWorkbook book, SmlWorksheet sheet, SmlCell cell) → Object?
evaluateCell API.
recalculate(SmlWorkbook book) → List<String>
recalculate API.