GlyphOutline class

Decoded TrueType glyf outline.

Constructors

GlyphOutline({required int glyphId, required int xMin, required int yMin, required int xMax, required int yMax, required List<GlyphPathCommand> commands, required List<int> componentGlyphIds})
GlyphOutline API.

Properties

commands → List<GlyphPathCommand>
commands API.
final
componentGlyphIds → List<int>
componentGlyphIds API.
final
glyphId → int
glyphId API.
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
isEmpty API.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xMax → int
xMax API.
final
xMin → int
xMin API.
final
yMax → int
yMax API.
final
yMin → int
yMin API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited