GraphemeClusters class abstract final

Class GraphemeClusters.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

indexAt(List<GraphemeCluster> clusters, int offset) → int
Returns the cluster index containing logical UTF-16 offset.
segment(String text) → List<GraphemeCluster>
segment API.