MemoryByteSource class

In-memory ByteSource backed by a single Uint8List.

Implemented types

Constructors

MemoryByteSource(Uint8List _bytes)
MemoryByteSource API.

Properties

hashCode → int
The hash code for this object.
no setterinherited
length → int
length API.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(int offset, int length) → Uint8List
read API.
override
toString() → String
A string representation of this object.
inherited
view(int offset, int length) → Uint8List
view API.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited