OfficeRepairResult class

Class OfficeRepairResult.

Constructors

OfficeRepairResult({required OfficeDiagnosis diagnosis, required List<OfficeIssue> repaired, required List<OfficeIssue> remaining, Uint8List? bytes, OpcPackage? package})
OfficeRepairResult API.

Properties

bytes → Uint8List?
bytes API.
final
diagnosis → OfficeDiagnosis
diagnosis API.
final
hashCode → int
The hash code for this object.
no setterinherited
package → OpcPackage?
package API.
final
remaining → List<OfficeIssue>
remaining API.
final
repaired → List<OfficeIssue>
repaired API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
succeeded → bool
succeeded API.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited