OfficeSpellIssue class

One misspelled span the host can underline or offer replacements for.

Constructors

OfficeSpellIssue({required int start, required int end, required String word, List<String> suggestions = const <String>[]})
OfficeSpellIssue API.
const

Properties

end → int
end API.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → int
start API.
final
suggestions → List<String>
suggestions API.
final
word → String
word API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited