PdfDisplayList class

Device-independent page paint ops (ISO 32000 content stream result).

Constructors

PdfDisplayList({required PdfPageInfo page, List<PdfPaintOp>? ops, List<PdfTextRun>? runs, List<PdfHotspot>? hotspots})
PdfDisplayList API.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hotspots → List<PdfHotspot>
hotspots API.
final
ops → List<PdfPaintOp>
ops API.
final
page → PdfPageInfo
page API.
final
plainText → String
plainText API.
no setter
runs → List<PdfTextRun>
Extractable / selectable text in visual order.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited