PdfEmbeddedFace class

One embedded CID face written as /FontFile2.

Constructors

PdfEmbeddedFace({required FontSubset subset, required SfntFont source, required String resourceName})
PdfEmbeddedFace API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourceName → String
PDF resource name such as F1 or F3.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → SfntFont
source API.
final
subset → FontSubset
subset API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited