PdfPage class

Class PdfPage.

Constructors

PdfPage({required double width, required double height, required Uint8List content, List<PdfEmbeddedImage> images = const <PdfEmbeddedImage>[], List<PdfLinkAnnot> links = const <PdfLinkAnnot>[]})
PdfPage API.

Properties

content → Uint8List
content API.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
height API.
final
images → List<PdfEmbeddedImage>
images API.
final
links API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
width API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited