PdfRect class

Class PdfRect.

Constructors

PdfRect({required double x, required double y, required double width, required double height})
PdfRect API.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
height API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
width API.
final
x → double
x API.
final
y → double
y API.
final

Methods

contains(double px, double py) → bool
contains API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited