PdfSignatureStatus enum

How a signature field is treated (P6.6).

Inheritance
Available extensions

Values

none → const PdfSignatureStatus

No /Sig fields.

unverified → const PdfSignatureStatus

/ByteRange covers the file except /Contents; PKCS#7 / CMS is not checked.

broken → const PdfSignatureStatus

/ByteRange missing or does not cover the file (excluding /Contents).

unsupported → const PdfSignatureStatus

Filter / SubFilter is not a Standard CMS name we inspect.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PdfSignatureStatus>
A constant List of the values in this enum, in order of their declaration.