PmlAnimPreset enum

Enum PmlAnimPreset.

Inheritance
Available extensions

Values

appear → const PmlAnimPreset
fade → const PmlAnimPreset
flyIn → const PmlAnimPreset
floatIn → const PmlAnimPreset
peekIn → const PmlAnimPreset
riseUp → const PmlAnimPreset
split → const PmlAnimPreset
wipe → const PmlAnimPreset
grow → const PmlAnimPreset
growTurn → const PmlAnimPreset
zoom → const PmlAnimPreset
swivel → const PmlAnimPreset
bounce → const PmlAnimPreset
pulse → const PmlAnimPreset
spin → const PmlAnimPreset
teeter → const PmlAnimPreset
growShrink → const PmlAnimPreset
disappear → const PmlAnimPreset
fadeOut → const PmlAnimPreset
flyOut → const PmlAnimPreset
shrink → const PmlAnimPreset
pathLine → const PmlAnimPreset
pathArc → const PmlAnimPreset

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<PmlAnimPreset>
A constant List of the values in this enum, in order of their declaration.