PmlMorphFrame class

Interpolated shape drawn during a Morph transition.

Constructors

PmlMorphFrame({required PmlShape shape, required PmlTransform transform, required String fillColor, required String text, required String textColor, required double fontSizePt, required double opacity, required List<PmlPathPoint> path, required PmlShapePreset preset, required PmlMorphRole role})
PmlMorphFrame API.
const

Properties

fillColor → String
fillColor API.
final
fontSizePt → double
fontSizePt API.
final
hashCode → int
The hash code for this object.
no setterinherited
opacity → double
opacity API.
final
path → List<PmlPathPoint>
path API.
final
preset → PmlShapePreset
preset API.
final
role → PmlMorphRole
role API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape → PmlShape
shape API.
final
text → String
text API.
final
textColor → String
textColor API.
final
transform → PmlTransform
transform API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited