SmlTable class
An Excel Table (ListObject).
Constructors
Properties
- bandedRows ↔ bool
-
bandedRows API.
getter/setter pair
- dataRange → SmlRange
-
dataRange API.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerRow ↔ bool
-
headerRow API.
getter/setter pair
- name ↔ String
-
name API.
getter/setter pair
- range ↔ SmlRange
-
range API.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dataRangeForColumn(
SmlWorksheet sheet, String header) → SmlRange? - dataRangeForColumn API.
-
headerName(
SmlWorksheet sheet, int col) → String - headerName API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolveRef(
SmlWorksheet sheet, String token) → SmlRange? - resolveRef API.