VisualPalette class abstract final

Class VisualPalette.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

nextBorder(String current) → String
nextBorder API.
nextFill(String current) → String
nextFill API.

Constants

borders → const List<String>
borders API.
fills → const List<String>
fills API.