WmlObject class

Class WmlObject.

Inheritance

Constructors

WmlObject({required String relationshipId, IsolatedEmbeddedPackage? embedded, double width = 200, double height = 120})
WmlObject API.

Properties

embedded ↔ IsolatedEmbeddedPackage?
embedded API.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
height API.
getter/setter pair
relationshipId ↔ String
relationshipId API.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ double
width API.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited