WmlTableCell class

Class WmlTableCell.

Constructors

WmlTableCell({List<WmlBlock>? blocks, int gridSpan = 1, WmlVMerge vMerge = WmlVMerge.none, double? width, String? fillColor, bool? borderTop, bool? borderBottom, bool? borderLeft, bool? borderRight})
WmlTableCell API.

Properties

blocks ↔ List<WmlBlock>
blocks API.
getter/setter pair
borderBottom ↔ bool?
borderBottom API.
getter/setter pair
borderLeft ↔ bool?
borderLeft API.
getter/setter pair
borderRight ↔ bool?
borderRight API.
getter/setter pair
borderTop ↔ bool?
null inherits table grid; false is w:val="nil" / none.
getter/setter pair
fillColor ↔ String?
fillColor API.
getter/setter pair
gridSpan ↔ int
gridSpan API.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vMerge ↔ WmlVMerge
vMerge API.
getter/setter pair
width ↔ double?
width API.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited