quds_office_engine_optional library

Optional APIs that are not part of the default engine surface.

Import this library only when a host needs PPT media package IO. Raster “diagram” visuals stay in quds_office_engine; real DrawingML SmartArt (dgm:) remains out of scope.

Classes

PptxMediaIo
Optional PPT media part IO (not on the default engine export surface).