ActionItem class
An action with an owner and a due string.
Constructors
- ActionItem({required String task, String owner = '', String due = ''})
-
ActionItem API.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited