BriefingTemplate class
Status briefing: summary, optional metrics, optional chart, next steps.
Constructors
-
BriefingTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.narrative, SfntFont? font, SfntFont? fontBold, required TemplateParty author, required String title, String summary = '', List<
BriefMetric> metrics = const <BriefMetric>[], List<ChartPoint> ? chart, List<String> next = const <String>[], BriefingLabels labels = const BriefingLabels(), }) - BriefingTemplate API.
Properties
-
author API.
final
-
chart
→ List<
ChartPoint> ? -
chart API. Null omits the chart.
final
- direction → TextDirection
-
direction API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → BriefingLabels
-
labels API.
final
-
metrics
→ List<
BriefMetric> -
metrics API.
final
-
next
→ List<
String> -
next API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String
-
summary API.
final
- theme → TemplateTheme
-
theme API.
final
- title → String
-
title API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited