CertificateLabels class
Certificate labels.
Constructors
- CertificateLabels({String document = 'Certificate', String presentedTo = 'Presented to', String date = 'Date'})
-
CertificateLabels API.
const
Properties
- date → String
-
date API.
final
- document → String
-
document API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- presentedTo → String
-
presentedTo API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited