DeliveryNoteTemplate class
Delivery note. detail is the second quantity (shipped).
Constructors
-
DeliveryNoteTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.commerce, SfntFont? font, SfntFont? fontBold, required TemplateParty sender, required TemplateParty receiver, List<
TradeLine> lines = const <TradeLine>[], TradeLabels labels = const TradeLabels(document: 'Delivery note', from: 'Sender', to: 'Receiver', extra: 'Ship date', quantity: 'Ordered', unit: 'Shipped'), String number = '', String date = '', String shipDate = '', String? notes, List<SignSlot> signs = const <SignSlot>[]}) - DeliveryNoteTemplate API.
Properties
- date → String
-
date API.
final
- direction → TextDirection
-
direction API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → TradeLabels
-
labels API.
final
-
lines
→ List<
TradeLine> -
lines API.
final
- notes → String?
-
notes API.
final
- number → String
-
number API.
final
- receiver → TemplateParty
-
receiver API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → TemplateParty
-
sender API.
final
- shipDate → String
-
shipDate API.
final
-
signs
→ List<
SignSlot> -
signs API.
final
- theme → TemplateTheme
-
theme API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited