ExpenseLabels class
Labels for an expense claim.
Constructors
Properties
- amount → String
-
amount API.
final
- category → String
-
category API.
final
- claimant → String
-
claimant API.
final
- date → String
-
date API.
final
- document → String
-
document API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- note → String
-
note API.
final
- notes → String
-
notes API.
final
- purpose → String
-
purpose API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → String
-
total API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited