ExpenseTemplate class

Expense claim.

Constructors

ExpenseTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.finance, SfntFont? font, SfntFont? fontBold, required TemplateParty claimant, List<ExpenseLine> lines = const <ExpenseLine>[], required String total, ExpenseLabels labels = const ExpenseLabels(), String purpose = '', String date = '', String? notes, String footer = '', List<SignSlot> signs = const <SignSlot>[]})
ExpenseTemplate API.

Properties

claimant → TemplateParty
claimant API.
final
date → String
date API.
final
direction → TextDirection
direction API.
final
font → SfntFont?
font API.
final
fontBold → SfntFont?
fontBold API.
final
footer API.
final
hashCode → int
The hash code for this object.
no setterinherited
labels → ExpenseLabels
labels API.
final
lines → List<ExpenseLine>
lines API.
final
notes → String?
notes API.
final
purpose → String
purpose API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signs → List<SignSlot>
signs API.
final
theme → TemplateTheme
theme API.
final
total → String
total API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() → Uint8List
save API.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited