InspectionLabels class

Inspection labels. Counts are computed from CheckItem.mark.

Constructors

InspectionLabels({String document = 'Inspection', String site = 'Site', String when = 'When', String inspector = 'Inspector', String pass = 'Pass', String fail = 'Fail', String open = 'Open', String item = 'Item', String result = 'Result', String note = 'Note', Map<CheckMark, String> marks = const <CheckMark, String>{CheckMark.open : 'Open', CheckMark.done : 'Done', CheckMark.pass : 'Pass', CheckMark.fail : 'Fail', CheckMark.na : 'N/A'}})
InspectionLabels API.
const

Properties

document → String
document API.
final
fail → String
fail API.
final
hashCode → int
The hash code for this object.
no setterinherited
inspector → String
inspector API.
final
item → String
item API.
final
marks → Map<CheckMark, String>
marks API.
final
note → String
note API.
final
open → String
open API.
final
pass → String
pass API.
final
result → String
result API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
site → String
site API.
final
when → String
when API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
word(CheckMark value) → String
word API.

Operators

operator ==(Object other) → bool
The equality operator.
inherited