InspectionTemplate class
Field inspection. Pass, fail, and open counts are derived from items.
Constructors
-
InspectionTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.operations, SfntFont? font, SfntFont? fontBold, required TemplateParty inspector, required String site, List<
CheckItem> items = const <CheckItem>[], InspectionLabels labels = const InspectionLabels(), String when = '', String? notes, List<SignSlot> signs = const <SignSlot>[]}) - InspectionTemplate API.
Properties
- direction → TextDirection
-
direction API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inspector → TemplateParty
-
inspector API.
final
-
items
→ List<
CheckItem> -
items API.
final
- labels → InspectionLabels
-
labels API.
final
- notes → String?
-
notes API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
signs
→ List<
SignSlot> -
signs API.
final
- site → String
-
site API.
final
- theme → TemplateTheme
-
theme API.
final
- when → String
-
when API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited