LetterTemplate class
Formal letter. Paragraphs are caller text in either language.
Constructors
-
LetterTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.people, SfntFont? font, SfntFont? fontBold, required TemplateParty sender, required TemplateParty recipient, required String subject, List<
String> paragraphs = const <String>[], LetterLabels labels = const LetterLabels(), String date = '', String reference = '', SignSlot? sign, }) - LetterTemplate API.
Properties
- date → String
-
date API.
final
- direction → TextDirection
-
direction API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → LetterLabels
-
labels API.
final
-
paragraphs
→ List<
String> -
paragraphs API.
final
- recipient → TemplateParty
-
recipient API.
final
- reference → String
-
reference API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sender → TemplateParty
-
sender API.
final
- sign → SignSlot?
-
sign API.
final
- subject → String
-
subject API.
final
- theme → TemplateTheme
-
theme API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited