ListingTemplate class
A filtered table. columns is the logical order; RTL flips it.
Constructors
-
ListingTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.data, SfntFont? font, SfntFont? fontBold, required TemplateParty owner, required List<
String> columns, List<List< rows = const <List<String>>[], ListingLabels labels = const ListingLabels(), String filter = '', })String> > - ListingTemplate API.
Properties
-
columns
→ List<
String> -
columns API.
final
- direction → TextDirection
-
direction API.
final
- filter → String
-
filter API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → ListingLabels
-
labels API.
final
- owner → TemplateParty
-
owner API.
final
-
rows
→ List<
List< String> > -
rows API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → TemplateTheme
-
theme API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited