MemoTemplate class
Internal memo. Sections are heading plus body, in the caller's language.
Constructors
-
MemoTemplate({TextDirection direction = TextDirection.ltr, TemplateTheme theme = TemplateThemes.narrative, SfntFont? font, SfntFont? fontBold, required TemplateParty from, required TemplateParty to, required String subject, List<
TemplateSection> sections = const <TemplateSection>[], MemoLabels labels = const MemoLabels(), String date = '', }) - MemoTemplate API.
Properties
- date → String
-
date API.
final
- direction → TextDirection
-
direction API.
final
- font → SfntFont?
-
font API.
final
- fontBold → SfntFont?
-
fontBold API.
final
-
footer API.
final
- from → TemplateParty
-
from API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labels → MemoLabels
-
labels API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sections
→ List<
TemplateSection> -
sections API.
final
- subject → String
-
subject API.
final
- theme → TemplateTheme
-
theme API.
final
- to → TemplateParty
-
to API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - save API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited