MinutesLabels class
Minutes labels.
Constructors
Properties
- actions → String
-
actions API.
final
- attendees → String
-
attendees API.
final
- decisions → String
-
decisions API.
final
- document → String
-
document API.
final
- due → String
-
due API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- owner → String
-
owner API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task → String
-
task API.
final
- when → String
-
when API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited