SheetKind enum

Which blocks a SheetTemplate paints.

Inheritance
Available extensions

Values

trade → const SheetKind

Parties, lines, and optional money totals.

ledger → const SheetKind

Facts plus a movement table.

letter → const SheetKind

Parties, paragraphs, and a sign-off.

award → const SheetKind

Landscape award.

check → const SheetKind

Facts plus a mark table.

brief → const SheetKind

Sections, optional chart, next steps.

listing → const SheetKind

Filter facts plus a record table.

score → const SheetKind

Metric cards and an optional chart.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<SheetKind>
A constant List of the values in this enum, in order of their declaration.