SheetLabels class
Headings for a SheetTemplate. Replace every string for another language.
Constructors
-
SheetLabels({required String document, String from = 'From', String to = 'To', String number = 'Number', String date = 'Date', String extra = 'Reference', String subject = 'Subject', String notes = 'Notes', String subtotal = 'Subtotal', String tax = 'Tax', String total = 'Total', String presentedTo = 'Presented to', List<
String> columns = const <String>['Description', 'Detail', 'Amount']}) -
SheetLabels API.
const
Properties
-
columns
→ List<
String> -
columns API. Logical order. RTL flips the table.
final
- date → String
-
date API.
final
- document → String
-
document API.
final
- extra → String
-
extra API.
final
- from → String
-
from API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- notes → String
-
notes API.
final
- number → String
-
number API.
final
- presentedTo → String
-
presentedTo API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
subject API.
final
- subtotal → String
-
subtotal API.
final
- tax → String
-
tax API.
final
- to → String
-
to API.
final
- total → String
-
total API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited