StatementLabels class

Column labels for a statement.

Constructors

StatementLabels({String document = 'Statement', String account = 'Account', String period = 'Period', String opening = 'Opening', String closing = 'Closing', String date = 'Date', String detail = 'Detail', String debit = 'Debit', String credit = 'Credit', String balance = 'Balance', String notes = 'Notes'})
StatementLabels API.
const

Properties

account → String
account API.
final
balance → String
balance API.
final
closing → String
closing API.
final
credit → String
credit API.
final
date → String
date API.
final
debit → String
debit API.
final
detail → String
detail API.
final
document → String
document API.
final
hashCode → int
The hash code for this object.
no setterinherited
notes → String
notes API.
final
opening → String
opening API.
final
period → String
period API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited