StatementLine class
One movement on a statement. Amounts are already formatted.
Constructors
Properties
- balance → String
-
balance API.
final
- credit → String
-
credit API.
final
- date → String
-
date API.
final
- debit → String
-
debit API.
final
- detail → String
-
detail API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited