The template index. Construct the class named on each TemplateRef.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
all
→ List<
TemplateRef> -
all API.
no setter
Static Methods
-
inCategory(
TemplateCategory category) → List< TemplateRef> - inCategory API.
Constants
- agenda → const TemplateRef
- agenda API.
- briefing → const TemplateRef
- briefing API.
- certificate → const TemplateRef
- certificate API.
- checklist → const TemplateRef
- checklist API.
-
core
→ const List<
TemplateRef> - Core papers. The suite index adds the rest.
- delivery → const TemplateRef
- delivery API.
- expense → const TemplateRef
- expense API.
- inspection → const TemplateRef
- inspection API.
- invoice → const TemplateRef
- invoice API.
- kpi → const TemplateRef
- kpi API.
- letter → const TemplateRef
- letter API.
- listing → const TemplateRef
- listing API.
- memo → const TemplateRef
- memo API.
- minutes → const TemplateRef
- minutes API.
- payslip → const TemplateRef
- payslip API.
- quote → const TemplateRef
- quote API.
- receipt → const TemplateRef
- receipt API.
- statement → const TemplateRef
- statement API.