Default palettes. Override any field with TemplateTheme.copyWith.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- commerce → const TemplateTheme
- commerce API.
- data → const TemplateTheme
- data API.
- education → const TemplateTheme
- education API.
- finance → const TemplateTheme
- finance API.
- logistics → const TemplateTheme
- logistics API.
- narrative → const TemplateTheme
- narrative API.
- operations → const TemplateTheme
- operations API.
- people → const TemplateTheme
- people API.
- programs → const TemplateTheme
- programs API.
- property → const TemplateTheme
- property API.