Border class

Box border.

Constructors

Border({BorderSide top = BorderSide.none, BorderSide right = BorderSide.none, BorderSide bottom = BorderSide.none, BorderSide left = BorderSide.none})
Border API.
const
Border.all({String color = '000000', double width = 1})
all API.
factory

Properties

bottom → BorderSide
bottom API.
final
hashCode → int
The hash code for this object.
no setterinherited
left → BorderSide
left API.
final
right API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → BorderSide
top API.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited