BoxConstraints class
Flutter-style box constraints.
Constructors
- BoxConstraints({double minWidth = 0, double maxWidth = double.infinity, double minHeight = 0, double maxHeight = double.infinity})
-
BoxConstraints API.
const
- BoxConstraints.expand({double? width, double? height})
-
expand API.
factory
- BoxConstraints.loose(PwSize size)
- loose API.
- BoxConstraints.tight(PwSize size)
- tight API.
- BoxConstraints.tightFor({double? width, double? height})
-
Tight on the axes that are specified (same idea as Flutter / package:pdf).
factory
Properties
- hasBoundedHeight → bool
-
hasBoundedHeight API.
no setter
- hasBoundedWidth → bool
-
hasBoundedWidth API.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTight → bool
-
True when min and max are equal on both axes.
no setter
- maxHeight → double
-
maxHeight API.
final
- maxWidth → double
-
maxWidth API.
final
- minHeight → double
-
minHeight API.
final
- minWidth → double
-
minWidth API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
constrain(
PwSize size) → PwSize - constrain API.
-
constrainHeight(
[double height = double.infinity]) → double - constrainHeight API.
-
constrainWidth(
[double width = double.infinity]) → double - constrainWidth API.
-
deflate(
EdgeInsets insets) → BoxConstraints - deflate API.
-
loosen(
) → BoxConstraints - loosen API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tighten(
{double? width, double? height}) → BoxConstraints - tighten API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited