Container class
Color + padding + alignment + constraints.
Constructors
- Container({Widget? child, double? width, double? height, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, AlignmentGeometry? alignment, BoxDecoration? decoration, String? color, BoxConstraints? constraints})
-
Container API.
const
Properties
- alignment → AlignmentGeometry?
-
alignment API.
final
- child → Widget?
-
child API.
final
- color → String?
-
color API.
final
- constraints → BoxConstraints?
-
Extra constraints (e.g.
minHeightfor table cells), like package:pdf.final - decoration → BoxDecoration?
-
decoration API.
final
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
height API.
final
- margin → EdgeInsetsGeometry?
-
margin API.
final
- padding → EdgeInsetsGeometry?
-
padding API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double?
-
width API.
final
Methods
-
layout(
Context context, BoxConstraints incoming) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited