CustomMultiChildLayout class

Arranges LayoutId children by a function, not a fixed flex rule.

Inheritance

Constructors

CustomMultiChildLayout({required List<LayoutId> children, required void performLayout(MultiChildLayoutHost host), PwSize size(BoxConstraints constraints)?})
CustomMultiChildLayout API.
const

Properties

children → List<LayoutId>
children API.
final
flowChildren → List<Widget>?
Children MultiPage should flow individually (vertical columns).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
performLayout → void Function(MultiChildLayoutHost host)
performLayout API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → PwSize Function(BoxConstraints constraints)?
size API. Null uses the incoming max when bounded, else the children.
final

Methods

layout(Context context, BoxConstraints constraints) → PwBox
layout API.
override
layoutSpan(Context context, BoxConstraints constraints) → SpanSlice?
Split across pages when constraints has a bounded height.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paintStamp(Context context, double pageW, double pageH) → void
Stamp paint. The default lays out and paints glyph by glyph.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited