Document class
Widget-tree PDF writer. Emits a native PdfDocument — does not rename it.
Constructors
Properties
-
author API.
final
- font → SfntFont?
-
Embedded glyf face. When null, Latin text uses Helvetica (
/F2).final - fontBold → SfntFont?
-
Bold face (package:pdf
ThemeData.base+ bold). When set, FontWeight.bold uses this Type0 font (/F3) instead of fake double-stroke.final - hashCode → int
-
The hash code for this object.
no setterinherited
- pageMode → String?
-
Unused catalog hint kept for
package:pdfcompatibility.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ThemeData?
-
theme API.
final
- title → String
-
title API.
final
Methods
-
addPage(
Page page) → void - addPage API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
save(
) → Uint8List - Composes the tree and writes a PDF 1.7 file (synchronous).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited