EdgeInsetsGeometry class abstract
Physical or start/end insets. Resolve with resolve before painting.
- Implementers
Constructors
- EdgeInsetsGeometry()
-
EdgeInsetsGeometry API.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
TextDirection direction) → EdgeInsets -
Physical insets for
direction. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited