EmptyBox class

Empty box.

Inheritance

Constructors

EmptyBox([PwSize size = PwSize.zero])
EmptyBox API.

Properties

baseline → double?
Distance from the top of this box to the alphabetic baseline, if any.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → PwSize
size API.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
noteDestination(Context context, PwOffset offset) → void
Record heading destinations once page placement is known.
inherited
paint(Context context, PwOffset offset) → void
paint API.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited