MultiChildLayoutHost class

Constructors

MultiChildLayoutHost(BoxConstraints constraints, Context _context, Map<Object, Widget> _children)
MultiChildLayoutHost API.

Properties

boxes → Map<Object, PwBox>
boxes API.
final
constraints → BoxConstraints
constraints API.
final
hashCode → int
The hash code for this object.
no setterinherited
offsets → Map<Object, PwOffset>
offsets API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

layoutChild(Object id, BoxConstraints constraints) → PwSize
layoutChild API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
positionChild(Object id, PwOffset offset) → void
positionChild API.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited