Text class
Single-run wrapped text.
Constructors
- Text(String text, {TextStyle? style, TextAlign? textAlign, TextDirection? textDirection, int? maxLines, bool softWrap = true, TextOverflow overflow = TextOverflow.clip})
-
Text API.
const
Properties
-
flowChildren
→ List<
Widget> ? -
Children MultiPage should flow individually (vertical columns).
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxLines → int?
-
maxLines API.
final
- overflow → TextOverflow
-
overflow API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softWrap → bool
-
softWrap API.
final
- style → TextStyle?
-
style API.
final
- text → String
-
text API.
final
- textAlign → TextAlign?
-
textAlign API.
final
- textDirection → TextDirection?
-
textDirection API.
final
Methods
-
layout(
Context context, BoxConstraints constraints) → PwBox -
layout API.
override
-
layoutSpan(
Context context, BoxConstraints constraints) → SpanSlice? -
Split across pages when
constraintshas a bounded height.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paintStamp(
Context context, double pageW, double pageH) → void -
Stamp paint. The default lays out and paints glyph by glyph.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited