TextStyle class

Run style. Measured and painted by the PDF layout engine.

Constructors

TextStyle({String? color, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, TextDecoration? decoration, double? lineSpacing, double? height, double? letterSpacing})
TextStyle API.
const

Properties

color → String?
RRGGBB or #RRGGBB.
final
decoration → TextDecoration?
decoration API.
final
fontSize → double?
fontSize API.
final
fontStyle → FontStyle?
fontStyle API.
final
fontWeight → FontWeight?
fontWeight API.
final
hashCode → int
The hash code for this object.
no setterinherited
height → double?
Line-height multiplier (Flutter / package:pdf TextStyle.height).
final
letterSpacing → double?
Extra advance between glyphs, in points.
final
lineHeightFactor → double
Effective line-height multiplier (package:pdf default is 1.0).
no setter
lineSpacing → double?
Line-height multiplier (legacy alias — prefer height).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({String? color, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, TextDecoration? decoration, double? lineSpacing, double? height, double? letterSpacing}) → TextStyle
copyWith API.
merge(TextStyle? other) → TextStyle
merge API.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited