ThemeData class
Inherited text + heading styles for a Document.
Constructors
- ThemeData({TextStyle defaultTextStyle = const TextStyle(fontSize: 11, color: '212121'), String? fontName, TextStyle? paragraphStyle, TextStyle? header0, TextStyle? header1, TextStyle? header2, TextStyle? header3, TextStyle? header4, TextStyle? header5, TextStyle tableHeader = const TextStyle(color: 'FFFFFF', fontWeight: FontWeight.bold, fontSize: 10), TextStyle tableCell = const TextStyle(fontSize: 10), TextStyle? bulletStyle})
-
ThemeData API.
const
- ThemeData.withFont({String? base})
-
withFont API.
factory
Properties
- bulletStyle → TextStyle?
-
Optional bullet text style.
final
- defaultTextStyle → TextStyle
-
defaultTextStyle API.
final
- fontName → String?
-
Optional face name (the writer still embeds Document.font).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header0 → TextStyle?
-
header0 API.
final
- header1 → TextStyle?
-
header1 API.
final
- header2 → TextStyle?
-
header2 API.
final
- header3 → TextStyle?
-
header3 API.
final
- header4 → TextStyle?
-
header4 API.
final
- header5 → TextStyle?
-
header5 API.
final
- paragraphStyle → TextStyle?
-
paragraphStyle API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableCell → TextStyle
-
Default style for Table.fromTextArray body cells.
final
- tableHeader → TextStyle
-
Default style for Table.fromTextArray headers.
final
Methods
-
copyWith(
{TextStyle? defaultTextStyle, TextStyle? paragraphStyle, TextStyle? tableHeader, TextStyle? tableCell, TextStyle? bulletStyle}) → ThemeData - copyWith API.
-
headerStyle(
int level) → TextStyle - headerStyle API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited