DocxDocumentBuilder class
Fluent Word builder: headings, lists, RTL tables, images, charts, comments.
Constructors
- DocxDocumentBuilder({bool? rtl, OfficeDocumentTheme? theme})
- DocxDocumentBuilder API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rtl → bool
-
rtl API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → OfficeDocumentTheme
-
theme API.
final
Methods
-
barChart(
{required String title, required List< ChartPoint> series, bool horizontal = true, int widthPx = 480, int heightPx = 300}) → void - barChart API.
-
bookmark(
String name) → void - bookmark API.
-
build(
{String? password}) → Uint8List - build API.
-
bulletList(
List< String> items) → void - bulletList API.
-
caption(
String text) → void - caption API.
- footer API.
-
header(
{String? left, String? center, String? right, bool pageNumber = false, bool date = false}) → void - header API.
-
heading(
String text, {int level = 1}) → void - heading API.
-
horizontalRule(
{String? colorHex}) → void - horizontalRule API.
-
hyperlink(
String text, String url) → void - hyperlink API.
-
image(
Uint8List bytes, {String name = 'image.png', int? widthPx, int? heightPx, int? maxWidthPx, String mime = 'image/png', String? caption}) → void - image API.
-
lineChart(
{required String title, required List< ChartSeries> series, bool markers = true, int widthPx = 480, int heightPx = 300}) → void - lineChart API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
note(
String text) → void - note API.
-
numberedList(
List< String> items, {int start = 1}) → void - numberedList API.
-
pageBreak(
) → void - pageBreak API.
-
paragraph(
String text, {bool bold = false, bool italic = false, int fontSizeHalfPoints = 20, String? colorHex, List< String> comments = const <String>[]}) → void - paragraph API.
-
pieChart(
{required String title, required List< ChartPoint> series, int widthPx = 480, int heightPx = 300}) → void - pieChart API.
-
spacer(
{int heightTwips = 240}) → void - spacer API.
-
stackedBarChart(
{required String title, required List< ChartSeries> series, bool horizontal = false, int widthPx = 480, int heightPx = 300}) → void - stackedBarChart API.
-
table(
List< List< rows, {bool hasHeader = true, String? headerFillHex, bool headerWhiteText = true, List<String> >int> ? colWidths, String cellAlign = 'left'}) → void - table API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited