LaidOutDocument class
Class LaidOutDocument.
Constructors
-
LaidOutDocument({required List<
LaidOutPage> pages, required WmlPageSize pageSize}) - LaidOutDocument API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pages
→ List<
LaidOutPage> -
pages API.
final
- pageSize → WmlPageSize
-
pageSize API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pageIndexAtContentY(
double contentY, double scale) → int - pageIndexAtContentY API.
-
pageStackTop(
int index, double scale) → double -
Vertical offset of page
indexin the stacked Word canvas (points ? scale). -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited