PdfAnnot class
Markup or navigation annotation (ISO 32000-1 12.5).
Constructors
-
PdfAnnot({required int id, required String subtype, required PdfRect rect, List<
PdfQuad> quads = const <PdfQuad>[], String contents = '', int color = 0xFFFFE066, String? uri, int? goToPage, double? goToY, List<List< ink = const <List<PdfPoint>>[], String fieldName = '', int? objectId})PdfPoint> > - PdfAnnot API.
Properties
- color ↔ int
-
ARGB color.
getter/setter pair
- contents ↔ String
-
contents API.
getter/setter pair
- fieldName ↔ String
-
fieldName API.
getter/setter pair
- goToPage ↔ int?
-
goToPage API.
getter/setter pair
- goToY ↔ double?
-
goToY API.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Stable editor id (not the COS object number).
final
-
ink
↔ List<
List< PdfPoint> > -
ink API.
getter/setter pair
- objectId ↔ int?
-
COS object number when loaded from the file.
getter/setter pair
-
quads
↔ List<
PdfQuad> -
quads API.
getter/setter pair
- rect ↔ PdfRect
-
rect API.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtype → String
-
subtype API.
final
- uri ↔ String?
-
uri API.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited