PdfCosStream class final
Stream object: dictionary plus undecoded bytes.
Constructors
- PdfCosStream(PdfCosDict dict, Uint8List raw)
- PdfCosStream API.
Properties
- dict → PdfCosDict
-
dict API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- raw → Uint8List
-
Raw bytes after
stream/ beforeendstream(possibly still filtered).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited