PdfDocInfo class
Document Info dictionary (ISO 32000-1 14.3.3).
Constructors
Properties
-
author API.
final
- creator → String
-
creator API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keywords → String
-
keywords API.
final
- pdfAConformance → String?
-
pdfAConformance API.
final
- pdfAPart → String?
-
pdfAPart API.
final
- producer → String
-
producer API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
subject API.
final
- title → String
-
title API.
final
- xmp → String
-
Raw XMP packet when present.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited