PdfOutlineNode class
Outline node (ISO 32000-1 12.3.3).
Constructors
-
PdfOutlineNode({required String title, int? pageIndex, double? destY, String? uri, List<
PdfOutlineNode> ? children}) - PdfOutlineNode API.
Properties
-
children
→ List<
PdfOutlineNode> -
children API.
final
- destY → double?
-
destY API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pageIndex → int?
-
pageIndex API.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
title API.
final
- uri → String?
-
uri API.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited