PmlLayout class
Class PmlLayout.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String
-
name API.
getter/setter pair
-
placeholders
→ List<
PmlShape> -
Real layout placeholders hosts can edit.
final
- placeholderText ↔ String
-
placeholderText API.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited