PmlSlideShow class
Click-driven slideshow clock for transitions and shape animations.
Constructors
- PmlSlideShow(PmlPresentation presentation)
- PmlSlideShow API.
Properties
- currentSlide → PmlSlide
-
currentSlide API.
no setter
- finished ↔ bool
-
finished API.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPreview → bool
-
isPreview API.
no setter
- isRewinding → bool
-
isRewinding API.
no setter
- isTransitioning → bool
-
isTransitioning API.
no setter
- isTransitionReverse → bool
-
isTransitionReverse API.
no setter
- outgoingSlide → PmlSlide?
-
outgoingSlide API.
no setter
- playingTransition → PmlSlideTransition?
-
playingTransition API.
no setter
- presentation → PmlPresentation
-
presentation API.
final
- presenting ↔ bool
-
presenting API.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slideIndex ↔ int
-
slideIndex API.
getter/setter pair
- transitionProgress → double
-
transitionProgress API.
no setter
Methods
-
elapse(
int ms) → void - elapse API.
-
next(
) → bool - next API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
previous(
) → bool - previous API.
-
sample(
int shapeId) → PmlAnimSample - sample API.
-
start(
{int from = 0, bool withTransition = false, bool previewOnly = false, bool endAfterTransition = false, bool autoPlayClicks = false, int? onlyAnimationIndex}) → void - start API.
-
stop(
) → void - stop API.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- previewHoldMs → const int
- previewHoldMs API.