SheetSerializer class
Class SheetSerializer.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
SmlWorkbook book, {bool recalculate = true}) → OpcPackage - write API.
-
writeBytes(
SmlWorkbook book, {bool recalculate = true, String? password}) → Uint8List - writeBytes API.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited