SmlComment class
A cell comment (comments.xml).
Constructors
- SmlComment({required SmlCellRef ref, required String text, String author = 'Quds Office'})
- SmlComment API.
Properties
-
author API.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ref ↔ SmlCellRef
-
ref API.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String
-
text API.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited