XmlCdata class
CDATA node.
Constructors
- XmlCdata(String text, {XmlElement? parent})
- XmlCdata API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent ↔ XmlElement?
-
parent API.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String
-
text API.
getter/setter pair
Methods
-
copy(
) → XmlCdata -
copy API.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
writeTo(
XmlWriter writer) → void -
writeTo API.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited